@@ -37,6 +37,7 @@
 #include <signal.h>
 #include <errno.h>
 #include <ctype.h>
+#include <dirent.h>
 #include <gpilotd/gnome-pilot-conduit.h>
 #include <gpilotd/gnome-pilot-conduit-standard-abs.h>
 
@@ -82,14 +83,13 @@ load_configuration (ConduitCfg **c,guint32 pilotId)
 	buf = gnome_config_get_string ("secret mode=0600");
 	(*c)->secret_mode =(mode_t)strtol (buf, NULL, 0);
 	g_free (buf);
-  
-	(*c)->dir = gnome_config_get_string ("dir");
 
+	(*c)->dir = gnome_config_get_string ("dir=");
+	
 	while ((*c)->dir[strlen ((*c)->dir)-1] == '/') {
 		(*c)->dir[strlen ((*c)->dir)-1] = '\0';
 	}
-
-
+	
 	(*c)->ignore_end=gnome_config_get_string ("ignore end");
 	(*c)->ignore_start=gnome_config_get_string ("ignore start");
 	gnome_config_pop_prefix ();
@@ -454,7 +454,7 @@ backup_directory (GnomePilotConduitStandardAbs *abs)
 	strcpy (tmp, GET_CONDUIT_CFG (abs)->dir);
 	filename = g_strdup_printf ("%s.old", tmp); 
 
-	if (g_file_test (filename, G_FILE_TEST_ISDIR)) {
+	if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
 		nuke_backup (abs);
 	}
 	
@@ -1183,7 +1183,7 @@ insert_ignore_space (GtkEditable    *editable, const gchar    *text,
 		     gint len, gint *position, void *data)
 {
 	gint i;
-	gchar *curname;
+	const gchar *curname;
 
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
